@@ -68,8 +68,8 @@ class LYRALightCurve(LightCurve):
         .. plot::
 
             import sunpy.lightcurve
-            from sunpy.data.sample import LYRA_LEVEL3_LIGHTCURVE
-            lyra = sunpy.lightcurve.LYRALightCurve.create(LYRA_LEVEL3_LIGHTCURVE)
+            from sunpy.data.sample import LYRA_LEVEL3_TIMESERIES
+            lyra = sunpy.lightcurve.LYRALightCurve.create(LYRA_LEVEL3_TIMESERIES)
             lyra.peek()
 
         Parameters
