@@ -25,6 +25,7 @@ class RHESSISummaryLightCurve(LightCurve):
     fidelity solar images in X rays (down to 3 keV) to gamma rays (1 MeV).
 
     RHESSI provides summary lightcurves in the following passbands
+
     * 3 - 6 keV
     * 6 - 12 keV
     * 12 - 25 keV
@@ -50,35 +51,25 @@ class RHESSISummaryLightCurve(LightCurve):
     * Mission Paper `<http://link.springer.com/article/10.1023%2FA%3A1022428818870>`_
     """
 
-    def peek(self, title="RHESSI Observing Summary Count Rate", **kwargs):
+    def peek(self):
         """Plots RHESSI Count Rate light curve. An example is shown below.
 
         .. plot::
 
             from sunpy import lightcurve as lc
-            from sunpy.data.sample import RHESSI_LIGHTCURVE
-            rhessi = lc.RHESSISummaryLightCurve.create(RHESSI_LIGHTCURVE)
+            from sunpy.data.sample import RHESSI_TIMESERIES
+            rhessi = lc.RHESSISummaryLightCurve.create(RHESSI_TIMESERIES)
             rhessi.peek()
 
-        Parameters
-        ----------
-        title : str
-            The title of the plot.
-
-        **kwargs : dict
-            Any additional plot arguments that should be used
-            when plotting.
-
         Returns
         -------
         fig : `~matplotlib.Figure`
             A plot figure.
+            
         """
         figure = plt.figure()
         axes = plt.gca()
 
-        #dates = matplotlib.dates.date2num(self.data.index)
-
         lc_linecolors = rhessi.hsi_linecolors()
 
         for lc_color, (item, frame) in zip(lc_linecolors, self.data.iteritems()):
@@ -125,8 +116,7 @@ class RHESSISummaryLightCurve(LightCurve):
             time_range = args[0]
         elif len(args) == 2:
             time_range = TimeRange(parse_time(args[0]), parse_time(args[1]))
-        url = rhessi.get_obssum_filename(time_range)
-        return url
+        return rhessi.get_obssum_filename(time_range)[0]
 
     @staticmethod
     def _parse_fits(filepath):
