@@ -1,8 +1,5 @@
 from __future__ import absolute_import, division, print_function
 
-__authors__ = ["Russell Hewett, Stuart Mumford"]
-__email__ = "stuart@mumford.me.uk"
-
 import os
 import glob
 from collections import OrderedDict
@@ -12,7 +9,6 @@ import astropy.io.fits
 
 import sunpy
 from sunpy.map.mapbase import GenericMap, MAP_CLASSES
-from sunpy.map.header import MapMeta
 from sunpy.map.compositemap import CompositeMap
 from sunpy.map.mapcube import MapCube
 
@@ -21,6 +17,8 @@ from sunpy.io.header import FileHeader
 
 from sunpy.util.net import download_file
 from sunpy.util import expand_list
+from sunpy.util.metadata import MetaDict
+from sunpy.util.config import get_and_create_download_dir
 
 from sunpy.util.datatype_factory_base import BasicRegistrationFactory
 from sunpy.util.datatype_factory_base import NoMatchError
@@ -30,6 +28,9 @@ from sunpy.extern import six
 
 from sunpy.extern.six.moves.urllib.request import urlopen
 
+__authors__ = ["Russell Hewett, Stuart Mumford"]
+__email__ = "stuart@mumford.me.uk"
+
 # Make a mock DatabaseEntry class if sqlalchemy is not installed
 
 try:
@@ -40,9 +41,10 @@ except ImportError:
 
 __all__ = ['Map', 'MapFactory']
 
+
 class MapFactory(BasicRegistrationFactory):
     """
-    Map(*args, **kwargs)
+    Map(\*args, \*\*kwargs)
 
     Map factory class.  Used to create a variety of Map objects.  Valid map types
     are specified by registering them with the factory.
@@ -61,7 +63,8 @@ class MapFactory(BasicRegistrationFactory):
 
     >>> mymap = sunpy.map.Map((data, header))   # doctest: +SKIP
 
-    headers are some base of `dict` or `collections.OrderedDict`, including `sunpy.io.header.FileHeader` or `sunpy.map.header.MapMeta` classes.
+    headers are some base of `dict` or `collections.OrderedDict`, including
+    `sunpy.io.header.FileHeader` or `sunpy.util.metadata.MetaDict` classes.
 
     * data, header pairs, not in tuples
 
@@ -89,11 +92,13 @@ class MapFactory(BasicRegistrationFactory):
 
     * Lists of any of the above
 
-    >>> mymap = sunpy.map.Map(['file1.fits', 'file2.fits', 'file3.fits', 'directory1/'])   # doctest: +SKIP
+    >>> mymap = sunpy.map.Map(['file1.fits', 'file2.fits', 'file3.fits', 'directory1/'])
+    # doctest: +SKIP
 
     * Any mixture of the above not in a list
 
-    >>> mymap = sunpy.map.Map((data, header), data2, header2, 'file1.fits', url_str, 'eit_*.fits')   # doctest: +SKIP
+    >>> mymap = sunpy.map.Map((data, header), data2, header2, 'file1.fits', url_str, 'eit_*.fits')
+    # doctest: +SKIP
     """
 
     def _read_file(self, fname, **kwargs):
@@ -101,17 +106,17 @@ class MapFactory(BasicRegistrationFactory):
             that file. """
 
         # File gets read here.  This needs to be generic enough to seamlessly
-        #call a fits file or a jpeg2k file, etc
+        # call a fits file or a jpeg2k file, etc
         pairs = read_file(fname, **kwargs)
 
         new_pairs = []
         for pair in pairs:
             filedata, filemeta = pair
             assert isinstance(filemeta, FileHeader)
-            #This tests that the data is more than 1D
+            # This tests that the data is more than 1D
             if len(np.shape(filedata)) > 1:
                 data = filedata
-                meta = MapMeta(filemeta)
+                meta = MetaDict(filemeta)
                 new_pairs.append((data, meta))
         return new_pairs
 
@@ -176,17 +181,17 @@ class MapFactory(BasicRegistrationFactory):
 
                 pair = (args[i], OrderedDict(args[i+1]))
                 data_header_pairs.append(pair)
-                i += 1 # an extra increment to account for the data-header pairing
+                i += 1   # an extra increment to account for the data-header pairing
 
             # File name
-            elif (isinstance(arg,six.string_types) and
+            elif (isinstance(arg, six.string_types) and
                   os.path.isfile(os.path.expanduser(arg))):
                 path = os.path.expanduser(arg)
                 pairs = self._read_file(path, **kwargs)
                 data_header_pairs += pairs
 
             # Directory
-            elif (isinstance(arg,six.string_types) and
+            elif (isinstance(arg, six.string_types) and
                   os.path.isdir(os.path.expanduser(arg))):
                 path = os.path.expanduser(arg)
                 files = [os.path.join(path, elem) for elem in os.listdir(path)]
@@ -194,8 +199,8 @@ class MapFactory(BasicRegistrationFactory):
                     data_header_pairs += self._read_file(afile, **kwargs)
 
             # Glob
-            elif (isinstance(arg,six.string_types) and '*' in arg):
-                files = glob.glob( os.path.expanduser(arg) )
+            elif (isinstance(arg, six.string_types) and '*' in arg):
+                files = glob.glob(os.path.expanduser(arg))
                 for afile in files:
                     data_header_pairs += self._read_file(afile, **kwargs)
 
@@ -204,11 +209,10 @@ class MapFactory(BasicRegistrationFactory):
                 already_maps.append(arg)
 
             # A URL
-            elif (isinstance(arg,six.string_types) and
+            elif (isinstance(arg, six.string_types) and
                   _is_url(arg)):
-                default_dir = sunpy.config.get("downloads", "download_dir")
                 url = arg
-                path = download_file(url, default_dir)
+                path = download_file(url, get_and_create_download_dir())
                 pairs = self._read_file(path, **kwargs)
                 data_header_pairs += pairs
 
@@ -220,12 +224,11 @@ class MapFactory(BasicRegistrationFactory):
                 raise ValueError("File not found or invalid input")
 
             i += 1
-        #TODO:
+        # TODO:
         # In the end, if there are already maps it should be put in the same
         # order as the input, currently they are not.
         return data_header_pairs, already_maps
 
-
     def __call__(self, *args, **kwargs):
         """ Method for running the factory. Takes arbitrary arguments and
         keyword arguments and passes them to a sequence of pre-registered types
@@ -266,7 +269,7 @@ class MapFactory(BasicRegistrationFactory):
         # matches the arguments.  If it does, use that type.
         for pair in data_header_pairs:
             data, header = pair
-            meta = MapMeta(header)
+            meta = MetaDict(header)
 
             try:
                 new_map = self._check_registered_widgets(data, meta, **kwargs)
@@ -311,7 +314,9 @@ class MapFactory(BasicRegistrationFactory):
             else:
                 candidate_widget_types = [self.default_widget_type]
         elif n_matches > 1:
-            raise MultipleMatchError("Too many candidate types identified ({0}).  Specify enough keywords to guarantee unique type identification.".format(n_matches))
+            raise MultipleMatchError("Too many candidate types identified ({0})."
+                                     "Specify enough keywords to guarantee unique type"
+                                     "identification.".format(n_matches))
 
         # Only one is found
         WidgetType = candidate_widget_types[0]
@@ -326,21 +331,25 @@ def _is_url(arg):
         return False
     return True
 
+
 class InvalidMapInput(ValueError):
     """Exception to raise when input variable is not a Map instance and does
     not point to a valid Map input file."""
     pass
 
+
 class InvalidMapType(ValueError):
     """Exception to raise when an invalid type of map is requested with Map
     """
     pass
 
+
 class NoMapsFound(ValueError):
     """Exception to raise when input does not point to any valid maps or files
     """
     pass
 
+
 Map = MapFactory(default_widget_type=GenericMap,
                  additional_validation_functions=['is_datasource_for'])
 Map.registry = MAP_CLASSES
