@@ -14,12 +14,12 @@ from astropy.utils.misc import isiterable
 
 from sunpy import config
 from sunpy.time import parse_time, TimeRange
-from sunpy.net.download import Downloader
-from sunpy.net.vso.vso import Results
+from sunpy.net.download import Downloader, Results
 from sunpy.net.attr import and_
 from sunpy.net.jsoc.attrs import walker
 from sunpy.extern.six.moves import urllib
 from sunpy.extern import six
+from sunpy.util import deprecated
 
 __all__ = ['JSOCClient', 'JSOCResponse']
 
@@ -44,6 +44,9 @@ class JSOCResponse(object):
     def __repr__(self):
         return repr(self.table)
 
+    def _repr_html_(self):
+        return self.table._repr_html_()
+
     def __len__(self):
         if self.table is None:
             return 0
@@ -96,9 +99,10 @@ class JSOCClient(object):
     Query JSOC for some HMI data at 45 second cadence:
 
     >>> from sunpy.net import jsoc
+    >>> from sunpy.net import attrs as a
     >>> client = jsoc.JSOCClient()
-    >>> response = client.query(jsoc.Time('2014-01-01T00:00:00', '2014-01-01T01:00:00'),
-    ...                         jsoc.Series('hmi.m_45s'), jsoc.Notify("sunpy@sunpy.org"))
+    >>> response = client.search(a.Time('2014-01-01T00:00:00', '2014-01-01T01:00:00'),
+    ...                         a.jsoc.Series('hmi.m_45s'), a.jsoc.Notify("sunpy@sunpy.org"))
 
     the response object holds the records that your query will return:
 
@@ -117,7 +121,7 @@ class JSOCClient(object):
 
     You can then make the request and download the data:
 
-    >>> res = client.get(response)   # doctest: +SKIP
+    >>> res = client.fetch(response)   # doctest: +SKIP
 
     This returns a Results instance which can be used to watch the progress
     of the download.
@@ -131,10 +135,11 @@ class JSOCClient(object):
 
     >>> import astropy.units as u
     >>> from sunpy.net import jsoc
+    >>> from sunpy.net import attrs as a
     >>> client = jsoc.JSOCClient()
-    >>> response = client.query(jsoc.Time('2014/1/1T00:00:00', '2014/1/1T00:00:36'),
-    ...                         jsoc.Series('aia.lev1_euv_12s'), jsoc.Segment('image'),
-    ...                         jsoc.Wavelength(171*u.AA), jsoc.Notify("sunpy@sunpy.org"))
+    >>> response = client.search(a.Time('2014/1/1T00:00:00', '2014/1/1T00:00:36'),
+    ...                         a.jsoc.Series('aia.lev1_euv_12s'), a.jsoc.Segment('image'),
+    ...                         a.jsoc.Wavelength(171*u.AA), a.jsoc.Notify("sunpy@sunpy.org"))
 
     the response object holds the records that your query will return:
 
@@ -149,6 +154,7 @@ class JSOCClient(object):
     You can then make the request:
 
     >>> requestIDs = client.request_data(response)
+    [u'JSOC_20140724_952']
 
     This returns a list of all the request identifiers for your query.
 
@@ -159,6 +165,7 @@ class JSOCClient(object):
     get into the queue.
 
     >>> status = client.check_request(requestIDs)
+    Request JSOC_20140724_955 was submitted 10 seconds ago, it is not ready to download.
 
     Once the status code is 0 you can download the data using the `get_request`
     method:
@@ -171,7 +178,7 @@ class JSOCClient(object):
     >>> res.wait(progress=True)   # doctest: +SKIP
     """
 
-    def query(self, *query, **kwargs):
+    def search(self, *query, **kwargs):
         """
         Build a JSOC query and submit it to JSOC for processing.
 
@@ -188,10 +195,11 @@ class JSOCClient(object):
 
         >>> import astropy.units as u
         >>> from sunpy.net import jsoc
+        >>> from sunpy.net import attrs as a
         >>> client = jsoc.JSOCClient()
-        >>> response = client.query(jsoc.Time('2010-01-01T00:00:00', '2010-01-01T01:00:00'),
-        ...                         jsoc.Series('aia.lev1_euv_12s'), jsoc.Wavelength(304*u.AA),
-        ...                         jsoc.Compression('rice'), jsoc.Segment('image'))
+        >>> response = client.search(a.Time('2010-01-01T00:00:00', '2010-01-01T01:00:00'),
+        ...                         a.jsoc.Series('aia.lev1_euv_12s'), a.jsoc.Wavelength(304*u.AA),
+        ...                         a.jsoc.Compression('rice'), a.jsoc.Segment('image'))
 
         Returns
         -------
@@ -201,16 +209,25 @@ class JSOCClient(object):
 
         return_results = JSOCResponse()
         query = and_(*query)
+        blocks = []
         for block in walker.create(query):
             iargs = kwargs.copy()
             iargs.update(block)
+            blocks.append(iargs)
 
             return_results.append(self._lookup_records(iargs))
 
-        return_results.query_args = iargs
+        return_results.query_args = blocks
 
         return return_results
 
+    @deprecated('0.8', alternative='JSOCClient.search')
+    def query(self, *query, **kwargs):
+        """
+        See `~sunpy.net.jsoc.jsoc.JSOCClient.search`
+        """
+        return self.search(*query, **kwargs)
+
     def request_data(self, jsoc_response, **kwargs):
         """
         Request that JSOC stages the data for download.
@@ -233,24 +250,28 @@ class JSOCClient(object):
             raise TypeError(warn_message.format(list(kwargs.keys())))
 
         # Do a multi-request for each query block
-        responses = self._multi_request(**jsoc_response.query_args)
-        for i, response in enumerate(responses):
-            if response.status_code != 200:
-                warn_message = "Query {0} retuned code {1}"
-                warnings.warn(
-                    Warning(warn_message.format(i, response.status_code)))
-                responses.pop(i)
-            elif response.json()['status'] != 2:
-                warn_message = "Query {0} returned status {1} with error {2}"
-                json_response = response.json()
-                json_status = json_response['status']
-                json_error = json_response['error']
-                warnings.warn(Warning(warn_message.format(i, json_status,
-                                                          json_error)))
-                responses.pop(i)
+        responses = []
+        requestIDs = []
+        for block in jsoc_response.query_args:
+            # Do a multi-request for each query block
+            responses.append(self._multi_request(**block))
+            for i, response in enumerate(responses[-1]):
+                if response.status_code != 200:
+                    warn_message = "Query {0} retuned code {1}"
+                    warnings.warn(
+                        Warning(warn_message.format(i, response.status_code)))
+                    responses.pop(i)
+                elif response.json()['status'] != 2:
+                    warn_message = "Query {0} retuned status {1} with error {2}"
+                    json_response = response.json()
+                    json_status = json_response['status']
+                    json_error = json_response['error']
+                    warnings.warn(Warning(warn_message.format(i, json_status,
+                                                              json_error)))
+                    responses[-1].pop(i)
 
-        # Extract the IDs from the JSON
-        requestIDs = [response.json()['requestid'] for response in responses]
+            # Extract the IDs from the JSON
+            requestIDs += [response.json()['requestid'] for response in responses[-1]]
 
         if return_responses:
             return responses
@@ -281,9 +302,9 @@ class JSOCClient(object):
             status = int(u.json()['status'])
 
             if status == 0:  # Data ready to download
-                print("Request {0} was exported at {1} and is ready to "\
+                print("Request {0} was exported at {1} and is ready to "
                       "download.".format(u.json()['requestid'],
-                                           u.json()['exptime']))
+                                         u.json()['exptime']))
             elif status == 1:
                 print_message = "Request {0} was submitted {1} seconds ago, " \
                                 "it is not ready to download."
@@ -299,8 +320,8 @@ class JSOCClient(object):
 
         return allstatus
 
-    def get(self, jsoc_response, path=None, overwrite=False, progress=True,
-            max_conn=5, downloader=None,sleep=10):
+    def fetch(self, jsoc_response, path=None, overwrite=False, progress=True,
+            max_conn=5, downloader=None, sleep=10):
         """
         Make the request for the data in jsoc_response and wait for it to be
         staged and then download the data.
@@ -341,7 +362,8 @@ class JSOCClient(object):
         jsoc_response.requestIDs = requestIDs
         time.sleep(sleep/2.)
 
-        r = None   # Needed when all requests ends in the else branch
+        r = Results(lambda x: None, done=lambda maps: [v['path'] for v in maps.values()])
+
         while requestIDs:
             for i, request_id in enumerate(requestIDs):
                 u = self._request_status(request_id)
@@ -352,13 +374,23 @@ class JSOCClient(object):
                 if u.status_code == 200 and u.json()['status'] == '0':
                     rID = requestIDs.pop(i)
                     r = self.get_request(rID, path=path, overwrite=overwrite,
-                                         progress=progress,downloader=downloader)
+                                         progress=progress, results=r)
 
                 else:
                     time.sleep(sleep)
 
         return r
 
+    @deprecated('0.8', alternative='JSOCClient.fetch')
+    def get(self, jsoc_response, path=None, overwrite=False, progress=True,
+            max_conn=5, downloader=None, sleep=10):
+        """
+        See `~sunpy.net.jsoc.jsoc.JSOCClient.fetch`
+        """
+        return self.fetch(jsoc_response, path=path, overwrite=overwrite, progress=progress,
+            max_conn=max_conn, downloader=downloader, sleep=sleep)
+
+
     def get_request(self, requestIDs, path=None, overwrite=False, progress=True,
                     max_conn=5, downloader=None, results=None):
         """
@@ -428,7 +460,8 @@ class JSOCClient(object):
                                         "has already been downloaded"
                         print(print_message.format(ar['filename']))
                         # Add the file on disk to the output
-                        results.map_.update({ar['filename']:{'path':os.path.join(path, ar['filename'])}})
+                        results.map_.update({ar['filename']:
+                                            {'path': os.path.join(path, ar['filename'])}})
 
                 if progress:
                     print_message = "{0} URLs found for download. Totalling {1}MB"
@@ -522,7 +555,7 @@ class JSOCClient(object):
 
         dataset = self._make_recordset(start_time, end_time, series, **kwargs)
         kwargs.pop('wavelength', None)
-        kwargs.pop('sample',None)
+        kwargs.pop('sample', None)
 
         # Build full POST payload
         payload = {'ds': dataset,
@@ -583,7 +616,7 @@ class JSOCClient(object):
         out_table = {}
         if 'keywords' in result:
             for col in result['keywords']:
-                out_table.update({col['name']:col['values']})
+                out_table.update({col['name']: col['values']})
 
             # sort the table before returning
             return astropy.table.Table(out_table)[keywords]
@@ -604,15 +637,18 @@ class JSOCClient(object):
         end_time = self._process_time(end_time)
         tr = TimeRange(start_time, end_time)
         returns = []
-        response, json_response = self._send_jsoc_request(start_time, end_time,\
+        response, json_response = self._send_jsoc_request(start_time, end_time,
                                                           series, **kwargs)
 
         # We skip these lines because a massive request is not a practical test.
         error_response = 'Request exceeds max byte limit of 100000MB'
         if (json_response['status'] == 3 and
-            json_response['error'] == error_response):  # pragma: no cover
-            returns.append(self._multi_request(tr.start(), tr.center(), series, **kwargs)[0])  # pragma: no cover
-            returns.append(self._multi_request(tr.center(), tr.end(), series, **kwargs)[0])  # pragma: no cover
+                json_response['error'] == error_response):  # pragma: no cover
+            returns.append(self._multi_request(tr.start(), tr.center(), series, **kwargs)[0])
+            # pragma: no cover
+            returns.append(self._multi_request(tr.center(), tr.end(), series, **kwargs)[0])
+            # pragma: no cover
+
         else:
             returns.append(response)
 
@@ -622,8 +658,14 @@ class JSOCClient(object):
         """
         GET the status of a request ID
         """
-        payload = {'op':'exp_status', 'requestid':request_id}
+        payload = {'op': 'exp_status', 'requestid': request_id}
         u = requests.get(JSOC_EXPORT_URL, params=payload)
 
         return u
 
+    @classmethod
+    def _can_handle_query(cls, *query):
+        chkattr = ['Series', 'Protocol', 'Notify', 'Compression', 'Wavelength',
+                   'Time', 'Segment']
+
+        return all([x.__class__.__name__ in chkattr for x in query])
