@@ -16,7 +16,7 @@ from astropy.utils.decorators import wraps
 
 from sunpy.tests import hash
 
-__all__ = ['skip_windows', 'skip_glymur', 'skip_ana', 'skip_wcsaxes', 'warnings_as_errors']
+__all__ = ['skip_windows', 'skip_glymur', 'skip_ana', 'warnings_as_errors']
 
 # SunPy's JPEG2000 capabilities rely on the glymur library.  First we check to
 # make sure that glymur imports correctly before proceeding.
@@ -45,23 +45,12 @@ else:
     SKIP_ANA = SKIP_ANA or False
 
 
-try:
-    try:
-        from astropy.visualization import wcsaxes
-    except ImportError:
-        import wcsaxes
-except ImportError:
-    SKIP_WCSAXES = True
-else:
-    SKIP_WCSAXES = False
-
 skip_windows = pytest.mark.skipif(platform.system() == 'Windows', reason="Windows")
 
 skip_glymur = pytest.mark.skipif(SKIP_GLYMUR, reason="Glymur can not be imported")
 
 skip_ana = pytest.mark.skipif(SKIP_ANA, reason="ANA is not available")
 
-skip_wcsaxes = pytest.mark.skipif(SKIP_WCSAXES, reason="wcsaxes is not available")
 
 @pytest.fixture
 def warnings_as_errors(request):
@@ -69,39 +58,6 @@ def warnings_as_errors(request):
 
     request.addfinalizer(lambda *args: warnings.resetwarnings())
 
-def assert_quantity_allclose(actual, desired, rtol=1.e-7, atol=0, err_msg='', verbose=True):
-    """
-    Raise an assertion if two objects are not equal up to desired tolerance.
-
-    This is a :class:`~astropy.units.Quantity`-aware version of
-    :func:`numpy.testing.assert_allclose`.
-    """
-
-    if isinstance(actual, u.Quantity) and isinstance(desired, u.Quantity):
-
-        if atol != 0:
-            if not isinstance(atol, u.Quantity):
-                raise TypeError("If `actual` and `desired` are Quantities, `atol` parameter should also be a Quantity")
-            else:
-                atol = atol.to(actual.unit).value
-
-        np.testing.assert_allclose(actual.value, desired.to(actual.unit).value,
-                                   rtol=rtol, atol=atol, err_msg=err_msg, verbose=verbose)
-
-    elif isinstance(actual, u.Quantity):
-        raise TypeError("If `actual` is a Quantity, `desired` should also be a Quantity")
-
-    elif isinstance(desired, u.Quantity):
-        raise TypeError("If `desired` is a Quantity, `actual` should also be a Quantity")
-
-    else:
-
-        if isinstance(atol, u.Quantity):
-            raise TypeError("If `actual` and `desired` are not Quantities, `atol` parameter should also not be a Quantity")
-
-        np.testing.assert_allclose(actual, desired,
-                                   rtol=rtol, atol=atol, err_msg=err_msg, verbose=verbose)
-
 new_hash_library = {}
 
 figure_test_pngfiles = {}
@@ -136,4 +92,5 @@ def figure_test(test_function):
             pytest.fail("Hash not present: {0}".format(name))
         else:
             assert hash.hash_library[name] == figure_hash
+        plt.close()
     return wrapper
